==> savane-1.0.2.tar.gz: savane/frontend/php/include/project/admin.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: admin.php,v 1.6 2004/03/13 18:22:06 yeupou Exp $
#
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) ...
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.



function project_admin_header($params)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':project_admin_header($params) ';
  global $DOCUMENT_ROOT,$group_id,$feedback,$group_name;

  $params['toptab']='home';
  $params['group']=$group_id;
  site_project_header($params);

  #	print 'BUG : Use of deprecated (5/5/2003) project_admin_header function !';

  echo '
	<P><B>
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/?group='.$group_name.'">Admin</A> |
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/userperms.php?group='.$group_name.'">User Permissions</A> |
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$group_name.'">Edit Public Info</A> |
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/history.php?group='.$group_name.'">Project History</A>
	<BR>';
  #	<A HREF="/project/admin/editpackages.php?group_id='.$group_id.'">Edit/Release Files</A> |
  echo '<A HREF="'.$GLOBALS['sys_home'].'people/createjob.php?group='.$group_name.'">Post Jobs</A> |
	<A HREF="'.$GLOBALS['sys_home'].'people/?group='.$group_name.'">Edit Jobs</A> ';
  #	<A HREF="/project/admin/editimages.php?group_id='.$group_id.'">Edit Screenshots</A>
  echo '
	</B>
	<P>';
}


function project_admin_footer($params)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':project_admin_footer($params) ';
  site_project_footer($params);
}


# Nicely html-formatted output of this group's audit trail

function show_grouphistory ($group_id)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_grouphistory ($group_id) ';
		# show the group_history rows that are relevant to
		# this group_id
  global $sys_datefmt;
  $result=group_get_history($group_id);
  $rows=db_numrows($result);

  if ($rows > 0) {

    echo '
		<h3>'
      ._("Group Change History").'</h3>
		<p>';
    $title_arr=array();
    $title_arr[]=_("Field");
    $title_arr[]=_("Value");
    $title_arr[]=_("Date");
    $title_arr[]=_("By");

    echo html_build_list_table_top ($title_arr);

    for ($i=0; $i < $rows; $i++) {
      $field=db_result($result, $i, 'field_name');
      echo '
			<tr class="'. html_get_alt_row_color($i) .'"><td>'.$field.'</td><td>';

      if ($field=='removed user') {
	echo user_getname(db_result($result, $i, 'old_value'));
      } else {
	echo db_result($result, $i, 'old_value');
      }
      echo '</td>'.
	'<td>'.format_date($sys_datefmt,db_result($result, $i, 'date')).'</td>'.
	'<td>'.db_result($result, $i, 'user_name').'</td></tr>';
    }

    echo '
		</table>';

  } else {
    echo '
		<h3>'
      ._("No Changes Have Been Made to This Group").'</h3>';
  }
}


function project_admin_registration_info ($row_grp)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':project_admin_registration_info ($row_grp)';
  $res_admin = db_query("SELECT user.user_id AS user_id,user.user_name AS user_name, user.realname AS realname, user.email AS email "
			. "FROM user,user_group "
			. "WHERE user_group.user_id=user.user_id AND user_group.group_id=".$row_grp['group_id']." AND "
			. "user_group.admin_flags = 'A'");


  print '<p><font class="preinput">'._("Project Admins").':</font><br> ';
  while ($row_admin = db_fetch_array($res_admin)) {
    print "<a href=\"".$GLOBALS['sys_home']."users/$row_admin[user_name]/\">$row_admin[realname] &lt;$row_admin[email]&gt;</a> ; ";
  }

  print '<p><font class="preinput">'._("Registration Date").':</font><br> '.format_date($sys_datefmt,$row_grp[register_time]);

  print '<p><font class="preinput">'._("System Group Name:").'</font><br> '.$row_grp[unix_group_name];

  print '<p><font class="preinput">'._("Submitted Description:").'</font><br> '.utils_make_links($row_grp[register_purpose]);

  print '<p><font class="preinput">'._("Required software:").'</font><br> '.utils_make_links($row_grp[required_software]);

  print '<p><font class="preinput">'._("Other comments:").'</font><br> '.utils_make_links($row_grp[other_comments]);

  print '<p>';
  print utils_registration_history($row_grp[unix_group_name]);

}

?>

==> savane-1.0.4.2.tar.gz: savane/frontend/php/include/project/admin.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: admin.php,v 1.7 2004/09/22 08:11:51 yeupou Exp $
#
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) ...
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.



function project_admin_header($params)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':project_admin_header($params) ';
  global $DOCUMENT_ROOT,$group_id,$feedback,$group_name;

  $params['toptab']='home';
  $params['group']=$group_id;
  site_project_header($params);

  #	print 'BUG : Use of deprecated (5/5/2003) project_admin_header function !';

  echo '
	<P><B>
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/?group='.$group_name.'">Admin</A> |
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/userperms.php?group='.$group_name.'">User Permissions</A> |
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$group_name.'">Edit Public Info</A> |
	<A HREF="'.$GLOBALS['sys_home'].'project/admin/history.php?group='.$group_name.'">Project History</A>
	<BR>';
  #	<A HREF="/project/admin/editpackages.php?group_id='.$group_id.'">Edit/Release Files</A> |
  echo '<A HREF="'.$GLOBALS['sys_home'].'people/createjob.php?group='.$group_name.'">Post Jobs</A> |
	<A HREF="'.$GLOBALS['sys_home'].'people/?group='.$group_name.'">Edit Jobs</A> ';
  #	<A HREF="/project/admin/editimages.php?group_id='.$group_id.'">Edit Screenshots</A>
  echo '
	</B>
	<P>';
}


function project_admin_footer($params)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':project_admin_footer($params) ';
  site_project_footer($params);
}


# Nicely html-formatted output of this group's audit trail

function show_grouphistory ($group_id)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_grouphistory ($group_id) ';
		# show the group_history rows that are relevant to
		# this group_id
  global $sys_datefmt;
  $result=group_get_history($group_id);
  $rows=db_numrows($result);

  if ($rows > 0) {

    echo '
		<h3>'
      ._("Group Change History").'</h3>
		<p>';
    $title_arr=array();
    $title_arr[]=_("Field");
    $title_arr[]=_("Value");
    $title_arr[]=_("Date");
    $title_arr[]=_("By");

    echo html_build_list_table_top ($title_arr);

    for ($i=0; $i < $rows; $i++) {
      $field=db_result($result, $i, 'field_name');
      echo '
			<tr class="'. html_get_alt_row_color($i) .'"><td>'.$field.'</td><td>';

      if ($field=='removed user') {
	echo user_getname(db_result($result, $i, 'old_value'));
      } else {
	echo db_result($result, $i, 'old_value');
      }
      echo '</td>'.
	'<td>'.format_date($sys_datefmt,db_result($result, $i, 'date')).'</td>'.
	'<td>'.db_result($result, $i, 'user_name').'</td></tr>';
    }

    echo '
		</table>';

  } else {
    echo '
		<h3>'
      ._("No Changes Have Been Made to This Group").'</h3>';
  }
}


function project_admin_registration_info ($row_grp)
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':project_admin_registration_info ($row_grp)';
  $res_admin = db_query("SELECT user.user_id AS user_id,user.user_name AS user_name, user.realname AS realname, user.email AS email "
			. "FROM user,user_group "
			. "WHERE user_group.user_id=user.user_id AND user_group.group_id=".$row_grp['group_id']." AND "
			. "user_group.admin_flags = 'A'");


  print '<p><font class="preinput">'._("Project Admins").':</font><br /> ';
  while ($row_admin = db_fetch_array($res_admin)) {
    print "<a href=\"".$GLOBALS['sys_home']."users/$row_admin[user_name]/\">$row_admin[realname] &lt;$row_admin[email]&gt;</a> ; ";
  }

  print '<p><font class="preinput">'._("Registration Date").':</font><br /> '.format_date($sys_datefmt,$row_grp[register_time]);

  print '<p><font class="preinput">'._("System Group Name:").'</font><br /> '.$row_grp[unix_group_name];

  print '<p><font class="preinput">'._("Submitted Description:").'</font><br /> '.utils_make_links($row_grp[register_purpose]);

  print '<p><font class="preinput">'._("Required software:").'</font><br /> '.utils_make_links($row_grp[required_software]);

  print '<p><font class="preinput">'._("Other comments:").'</font><br /> '.utils_make_links($row_grp[other_comments]);

  print '<p>';
  print utils_registration_history($row_grp[unix_group_name]);

}

?>
